@@ -22,7 +22,11 @@
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include "control-data.h"
 #include "spellchecker.h"
 #include "properties.h"
